==> dent-0.1.0.tar.gz: lib/src/core/dart_primitive_queries.dart <==
// Copyright 2019 terrier989@gmail.com.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import 'package:built_value/built_value.dart';
import 'package:built_value/serializer.dart';
import 'package:datastore/datastore.dart' show GeoPoint;

export 'package:datastore/datastore.dart' show GeoPoint;

part 'dart_primitive_queries.g.dart';

abstract class BoolQuery
    implements PrimitiveQuery, Built<BoolQuery, BoolQueryBuilder> {
  static Serializer<BoolQuery> get serializer => _$boolQuerySerializer;

  factory BoolQuery({
    bool isNull,
    bool value,
  }) = _$BoolQuery._;

  factory BoolQuery.build([void Function(BoolQueryBuilder b) updates]) =
      _$BoolQuery;

  BoolQuery._();

  /// Expected value.
  @nullable
  bool get value;
}

abstract class ComparablePrimitiveQuery<T> implements PrimitiveQuery {
  /// If non-null, matches only rows where value of the column is equal or less
  /// than the specified value.
  @nullable
  T get max;

  /// If non-null, matches only rows where value of the column is equal or
  /// greater than the specified value.
  @nullable
  T get min;

  /// If non-null, matches only rows where value of the column is equal to the
  /// specified value.
  @nullable
  T get value;
}

abstract class DateTimeQuery
    implements
        ComparablePrimitiveQuery<DateTime>,
        Built<DateTimeQuery, DateTimeQueryBuilder> {
  static Serializer<DateTimeQuery> get serializer => _$dateTimeQuerySerializer;

  factory DateTimeQuery({
    bool isNull,
    DateTime value,
  }) = _$DateTimeQuery._;

  factory DateTimeQuery.build([void Function(DateTimeQueryBuilder b) updates]) =
      _$DateTimeQuery;

  DateTimeQuery._();
}

abstract class DoubleQuery
    implements
        ComparablePrimitiveQuery<double>,
        Built<DoubleQuery, DoubleQueryBuilder> {
  static Serializer<DoubleQuery> get serializer => _$doubleQuerySerializer;

  factory DoubleQuery({
    bool isNull,
    double value,
    double min,
    double max,
  }) = _$DoubleQuery._;

  factory DoubleQuery.build([void Function(DoubleQueryBuilder b) updates]) =
      _$DoubleQuery;

  DoubleQuery._();
}

abstract class GeoPointQuery
    implements PrimitiveQuery, Built<GeoPointQuery, GeoPointQueryBuilder> {
  static Serializer<GeoPointQuery> get serializer => _$geoPointQuerySerializer;

  factory GeoPointQuery({
    double maxDistance,
    GeoPoint near,
  }) = _$GeoPointQuery._;

  factory GeoPointQuery.build([void Function(GeoPointQueryBuilder b) updates]) =
      _$GeoPointQuery;

  GeoPointQuery._();

  @nullable
  double get maxDistance;

  @nullable
  GeoPoint get near;
}

abstract class IntQuery
    implements ComparablePrimitiveQuery<int>, Built<IntQuery, IntQueryBuilder> {
  static Serializer<IntQuery> get serializer => _$intQuerySerializer;

  factory IntQuery({
    bool isNull,
    int value,
    int min,
    int max,
  }) = _$IntQuery._;

  factory IntQuery.build([void Function(IntQueryBuilder b) updates]) =
      _$IntQuery;

  IntQuery._();
}

abstract class ListQuery<T>
    implements Built<ListQuery<T>, ListQueryBuilder<T>> {
  static Serializer<ListQuery> get serializer => _$listQuerySerializer;

  factory ListQuery({
    T where,
  }) = _$ListQuery<T>._;

  factory ListQuery.build([void Function(ListQueryBuilder<T> b) updates]) =
      _$ListQuery<T>;

  ListQuery._();

  @nullable
  T get where;
}

abstract class PrimitiveQuery {
  /// True if null values should match.
  @nullable
  bool get isNull;
}

abstract class StringQuery
    implements
        ComparablePrimitiveQuery<String>,
        Built<StringQuery, StringQueryBuilder> {
  static Serializer<StringQuery> get serializer => _$stringQuerySerializer;

  factory StringQuery({
    bool isNull,
    String value,
    String min,
    String max,
  }) = _$StringQuery._;

  factory StringQuery.build([void Function(StringQueryBuilder b) updates]) =
      _$StringQuery;

  StringQuery._();
}

==> dent-0.2.0.tar.gz: lib/src/core/dart_primitive_queries.dart <==
// Copyright 2019 terrier989@gmail.com.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import 'package:built_value/built_value.dart';
import 'package:built_value/serializer.dart';
import 'package:database/database.dart' show GeoPoint;

export 'package:database/database.dart' show GeoPoint;

part 'dart_primitive_queries.g.dart';

abstract class BoolQuery
    implements PrimitiveQuery, Built<BoolQuery, BoolQueryBuilder> {
  static Serializer<BoolQuery> get serializer => _$boolQuerySerializer;

  factory BoolQuery({
    bool isNull,
    bool value,
  }) = _$BoolQuery._;

  factory BoolQuery.build([void Function(BoolQueryBuilder b) updates]) =
      _$BoolQuery;

  BoolQuery._();

  /// Expected value.
  @nullable
  bool get value;
}

abstract class ComparablePrimitiveQuery<T> implements PrimitiveQuery {
  /// If non-null, matches only rows where value of the column is equal or less
  /// than the specified value.
  @nullable
  T get max;

  /// If non-null, matches only rows where value of the column is equal or
  /// greater than the specified value.
  @nullable
  T get min;

  /// If non-null, matches only rows where value of the column is equal to the
  /// specified value.
  @nullable
  T get value;
}

abstract class DateTimeQuery
    implements
        ComparablePrimitiveQuery<DateTime>,
        Built<DateTimeQuery, DateTimeQueryBuilder> {
  static Serializer<DateTimeQuery> get serializer => _$dateTimeQuerySerializer;

  factory DateTimeQuery({
    bool isNull,
    DateTime value,
  }) = _$DateTimeQuery._;

  factory DateTimeQuery.build([void Function(DateTimeQueryBuilder b) updates]) =
      _$DateTimeQuery;

  DateTimeQuery._();
}

abstract class DoubleQuery
    implements
        ComparablePrimitiveQuery<double>,
        Built<DoubleQuery, DoubleQueryBuilder> {
  static Serializer<DoubleQuery> get serializer => _$doubleQuerySerializer;

  factory DoubleQuery({
    bool isNull,
    double value,
    double min,
    double max,
  }) = _$DoubleQuery._;

  factory DoubleQuery.build([void Function(DoubleQueryBuilder b) updates]) =
      _$DoubleQuery;

  DoubleQuery._();
}

abstract class GeoPointQuery
    implements PrimitiveQuery, Built<GeoPointQuery, GeoPointQueryBuilder> {
  static Serializer<GeoPointQuery> get serializer => _$geoPointQuerySerializer;

  factory GeoPointQuery({
    double maxDistance,
    GeoPoint near,
  }) = _$GeoPointQuery._;

  factory GeoPointQuery.build([void Function(GeoPointQueryBuilder b) updates]) =
      _$GeoPointQuery;

  GeoPointQuery._();

  @nullable
  double get maxDistance;

  @nullable
  GeoPoint get near;
}

abstract class IntQuery
    implements ComparablePrimitiveQuery<int>, Built<IntQuery, IntQueryBuilder> {
  static Serializer<IntQuery> get serializer => _$intQuerySerializer;

  factory IntQuery({
    bool isNull,
    int value,
    int min,
    int max,
  }) = _$IntQuery._;

  factory IntQuery.build([void Function(IntQueryBuilder b) updates]) =
      _$IntQuery;

  IntQuery._();
}

abstract class ListQuery<T>
    implements Built<ListQuery<T>, ListQueryBuilder<T>> {
  static Serializer<ListQuery> get serializer => _$listQuerySerializer;

  factory ListQuery({
    T where,
  }) = _$ListQuery<T>._;

  factory ListQuery.build([void Function(ListQueryBuilder<T> b) updates]) =
      _$ListQuery<T>;

  ListQuery._();

  @nullable
  T get where;
}

abstract class PrimitiveQuery {
  /// True if null values should match.
  @nullable
  bool get isNull;
}

abstract class StringQuery
    implements
        ComparablePrimitiveQuery<String>,
        Built<StringQuery, StringQueryBuilder> {
  static Serializer<StringQuery> get serializer => _$stringQuerySerializer;

  factory StringQuery({
    bool isNull,
    String value,
    String min,
    String max,
  }) = _$StringQuery._;

  factory StringQuery.build([void Function(StringQueryBuilder b) updates]) =
      _$StringQuery;

  StringQuery._();
}
